==> haskell-wai-conduit-3.0.0.4-601-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-conduit
version:              3.0.0.4
visibility:           public
id:                   wai-conduit-3.0.0.4-JhUkMpG0xfm56TtO95ln9Q
key:                  wai-conduit-3.0.0.4-JhUkMpG0xfm56TtO95ln9Q
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/yesodweb/wai
synopsis:             conduit wrappers for WAI
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-conduit>.

category:             Web, Conduit
abi:                  f266e15f8ef8bc866c150091b6da1026
exposed:              True
exposed-modules:      Network.Wai.Conduit
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-conduit-3.0.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-conduit-3.0.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-conduit-3.0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-conduit
hs-libraries:         HSwai-conduit-3.0.0.4-JhUkMpG0xfm56TtO95ln9Q
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-Hw2vqaXMslA26It0qcQIBG
    http-types-0.12.4-1DZFzfvJVK9AHfgKU8FkY3 transformers-0.5.6.2
    wai-3.2.4-LaZv3Kj0Ed9gV12y2mMCG

haddock-interfaces:   /usr/share/doc/haskell-wai-conduit/html/wai-conduit.haddock
haddock-html:         /usr/share/doc/haskell-wai-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-conduit-3.0.0.4-602-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-conduit
version:              3.0.0.4
visibility:           public
id:                   wai-conduit-3.0.0.4-AB3UyO8QWRU2ytqLydhxVm
key:                  wai-conduit-3.0.0.4-AB3UyO8QWRU2ytqLydhxVm
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/yesodweb/wai
synopsis:             conduit wrappers for WAI
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-conduit>.

category:             Web, Conduit
abi:                  2c64bf5ea6e05f206cad07bcd41b1e91
exposed:              True
exposed-modules:      Network.Wai.Conduit
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-conduit-3.0.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-conduit-3.0.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-conduit-3.0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-conduit
hs-libraries:         HSwai-conduit-3.0.0.4-AB3UyO8QWRU2ytqLydhxVm
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-86fl8mgs0PcICSp2A4xyva
    http-types-0.12.4-1DZFzfvJVK9AHfgKU8FkY3 transformers-0.5.6.2
    wai-3.2.4-LaZv3Kj0Ed9gV12y2mMCG

haddock-interfaces:   /usr/share/doc/haskell-wai-conduit/html/wai-conduit.haddock
haddock-html:         /usr/share/doc/haskell-wai-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
